@@ -3,7 +3,7 @@ use crate::*;
 pub trait ReadOnlyRegister: From<u8> {
     const ADDR: u8;
 
-    fn read<E, I2C: WriteRead<Error = E>>(i2c: &mut I2C) -> Result<Self, E> {
+    fn read<E, I2C: i2c::WriteRead<Error = E>>(i2c: &mut I2C) -> Result<Self, E> {
         let buf = &mut [0u8; 1];
         i2c.write_read(I2C_ADDR, &[Self::ADDR], buf)
             .map(|_| buf[0].into())
@@ -17,7 +17,7 @@ impl<RWR: ReadWriteRegister> ReadOnlyRegister for RWR {
 pub trait ReadWriteRegister: From<u8> + Into<u8> {
     const ADDR: u8;
 
-    fn write<E, I2C: Write<Error = E>>(self, i2c: &mut I2C) -> Result<(), E> {
+    fn write<E, I2C: i2c::Write<Error = E>>(self, i2c: &mut I2C) -> Result<(), E> {
         i2c.write(I2C_ADDR, &[Self::ADDR, self.into()])
     }
 }
